==> gnucash-2.6.10-1-aarch64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/report/standard-reports/general-journal.go <==
GOOF----LE-8-2.0      ] g 4       hY      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  general-journal	
	 	g  filenameS	f  general-journal.scm	
g  set-current-module	
 	
 	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:make-general-journal-report	 	g  process-use-modules	 	 	g  main	 	  	!g  
gnc-module	"! 	#" 	$g  gettext	%$ 	&% 	'g  gnc:module-load	(f  gnucash/report/report-system	)f  General Journal	*g  
reportname	+f  Register	,g  
regrptname	-f   22104e02654c4adba844ee75a3f8d173	.g  
regrptguid	/g  gnc:make-report	0g  +gnc:report-template-new-options/report-guid	1g  qof-query-create-for-splits	2g  qof-query-set-book	3g  gnc-get-current-book	4g  #gnc:query-set-match-non-voids-only!	5g  qof-query-set-sort-order	6g  SPLIT-TRANS	7g  TRANS-DATE-POSTED	8g  QUERY-DEFAULT-SORT	9g  qof-query-set-sort-increasing	:g  xaccQueryAddAccountMatch	;g  "gnc-account-get-descendants-sorted	<g  gnc-book-get-template-root	=g  QOF-GUID-MATCH-NONE	>g  
QOF-QUERY-AND	?g  for-each	@g  gnc:option-set-value	Ag  gnc:lookup-option	Bf  __reg	Cf  query	Dg  
gnc-query2scm	Ef  journal	Ff  double	Gf  debit-string	Hg  _	If  Debit	Jf  
credit-string	Kf  Credit	Lg  gnc:pagename-general	Mf  Title	Ng  gnc:pagename-display	Of  Date	Pg  'qof-book-use-split-action-for-num-field	Qf  
Num/Action	Rf  Num	Sf  Description	Tf  Account	Uf  Shares	Vf  Price	Wf  Amount	Xg  double	Yf  Running Balance	Zf  Totals	[g  !general-journal-options-generator	\g  (gnc:report-template-renderer/report-guid	]g  general-journal-renderer	^g  gnc:define-report	_g  version	`g  name	ag  report-guid	bf   25455562bd234dd0b048ecc5a8af9e43	cg  	menu-path	dg  gnc:menuname-asset-liability	eg  options-generator	fg  rendererC 5  h	  -  ]4
5 4 >  "  G   4       h   E   ] 45 6   =       g  filenamef  general-journal.scm
	
 		
   C>  "  G  4  >  "  G  4# >  "  G  4& >  "  G  4'i(
>  "  G  )*R+,R-.R/.   h   y   ] 6q       g  filenamef  general-journal.scm
	*
		+	 		
  g  nameg  gnc:make-general-journal-report CR0.,123456789:;<=>?@AB     h       ]  4L 56         g  l
		 g  name			 g  value				  g  filenamef  general-journal.scm
	P			Q			Q	$			Q			8			Q			8			7	 			   CCDEFGHIJKL*@AMN@A        h(      ]  4L 56             g  l
		" g  section		" g  name			" g  value			"  g  filenamef  general-journal.scm
	f			g	)	
	g	1		g			8		"	7	 		"   COPQRSTUVWXYZ /     h  u  ] 45 45 445 >  "  G  445 >  "  G  4	
  >  "  G  4>  "  G  4
4445 55>  "  G  4 O 45   45 45  >  "  G  4544  !5>  "  G  4" O # 4$45 5$  
% "  & ' ( ) * +, - .  	>  "  G   C       m      g  options
	 g  query	 g  section	  g  value	   g  filenamef  general-journal.scm
	0
		2			2			3			2			?			?		#	?		,	@		1	@	/	:	@		C	A		N	B		S	C		T	D		Y	A		b	E		w	G		|	I			J	 	J	" 	J	 	I	 	G	 	O	 	T	 	T	 	T	 	U	 	U	 	V	 	V	 	W	 	W	 	W	 	W	 	W	 	X	 	X	 	X	 	X	 	X	 	S	 	O	 	_	' 	^	 	7	 	8	 	_	 	8		7		e	!	j	%	j	&	k	
)	k	3/	k	
3	k	5	l	9	l	
?	m	C	m	
E	n	I	n	K	o	O	o	Q	p	U	p	W	q	[	q	]	s	_	s	b	s	d	t	h	t	j	u	n	u	q	i	v	e	 P	
  g  nameg  !general-journal-options-generator C[R\.,      h      ]45 6        g  
report-obj
		  g  filenamef  general-journal.scm
	~
	 		 	 		  g  nameg  general-journal-renderer C]R^i_`*iabcdi e[if]i6%      g  m
	
	$  g  filenamef  general-journal.scm		
	%	
 	
 	
 	 
 	"
 	"	 	"
 	$	 	$
 	%	 	%
	&		&
	*
	0
		~
	 	 	 	 		 	 		 	 	 
 		
   C6 

==> gnucash-2.6.13-1-aarch64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/report/standard-reports/general-journal.go <==
GOOF----LE-8-2.0      ] g 4       ha      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  general-journal	
	 	g  filenameS	f  general-journal.scm	
g  set-current-module	
 	
 	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:make-general-journal-report	 	g  process-use-modules	 	 	g  main	 	  	!g  
gnc-module	"! 	#" 	$g  gettext	%$ 	&% 	'g  gnc:module-load	(f  gnucash/report/report-system	)f  General Journal	*g  
reportname	+f  Register	,g  
regrptname	-f   22104e02654c4adba844ee75a3f8d173	.g  
regrptguid	/g  gnc:make-report	0g  +gnc:report-template-new-options/report-guid	1g  qof-query-create-for-splits	2g  qof-query-set-book	3g  gnc-get-current-book	4g  #gnc:query-set-match-non-voids-only!	5g  qof-query-set-sort-order	6g  SPLIT-TRANS	7g  TRANS-DATE-POSTED	8g  QUERY-DEFAULT-SORT	9g  qof-query-set-sort-increasing	:g  xaccQueryAddAccountMatch	;g  "gnc-account-get-descendants-sorted	<g  gnc-book-get-template-root	=g  QOF-GUID-MATCH-NONE	>g  
QOF-QUERY-AND	?g  for-each	@g  gnc:option-set-default-value	Ag  gnc:lookup-option	Bf  __reg	Cf  query	Dg  
gnc-query2scm	Ef  journal	Ff  double	Gf  debit-string	Hg  _	If  Debit	Jf  
credit-string	Kf  Credit	Lg  gnc:pagename-general	Mf  Title	Ng  gnc:pagename-display	Of  Date	Pg  'qof-book-use-split-action-for-num-field	Qf  
Num/Action	Rf  Num	Sf  Description	Tf  Account	Uf  Shares	Vf  Price	Wf  Amount	Xg  double	Yf  Running Balance	Zf  Totals	[g  !general-journal-options-generator	\g  (gnc:report-template-renderer/report-guid	]g  general-journal-renderer	^g  gnc:define-report	_g  version	`g  name	ag  report-guid	bf   25455562bd234dd0b048ecc5a8af9e43	cg  	menu-path	dg  gnc:menuname-asset-liability	eg  options-generator	fg  rendererC 5  h	  -  ]4
5 4 >  "  G   4       h   E   ] 45 6   =       g  filenamef  general-journal.scm
	
 		
   C>  "  G  4  >  "  G  4# >  "  G  4& >  "  G  4'i(
>  "  G  )*R+,R-.R/.   h   y   ] 6q       g  filenamef  general-journal.scm
	*
		+	 		
  g  nameg  gnc:make-general-journal-report CR0.,123456789:;<=>?@AB     h       ]  4L 56         g  l
		 g  name			 g  value				  g  filenamef  general-journal.scm
	P			Q			Q	$			Q			8			Q			8			7	 			   CCDEFGHIJKL*@AMN@A        h(      ]  4L 56             g  l
		" g  section		" g  name			" g  value			"  g  filenamef  general-journal.scm
	f			g	)	
	g	1		g			8		"	7	 		"   COPQRSTUVWXYZ /     h  u  ] 45 45 445 >  "  G  445 >  "  G  4	
  >  "  G  4>  "  G  4
4445 55>  "  G  4 O 45   45 45  >  "  G  4544  !5>  "  G  4" O # 4$45 5$  
% "  & ' ( ) * +, - .  	>  "  G   C       m      g  options
	 g  query	 g  section	  g  value	   g  filenamef  general-journal.scm
	0
		2			2			3			2			?			?		#	?		,	@		1	@	/	:	@		C	A		N	B		S	C		T	D		Y	A		b	E		w	G		|	I			J	 	J	" 	J	 	I	 	G	 	O	 	T	 	T	 	T	 	U	 	U	 	V	 	V	 	W	 	W	 	W	 	W	 	W	 	X	 	X	 	X	 	X	 	X	 	S	 	O	 	_	' 	^	 	7	 	8	 	_	 	8		7		e	!	j	%	j	&	k	
)	k	3/	k	
3	k	5	l	9	l	
?	m	C	m	
E	n	I	n	K	o	O	o	Q	p	U	p	W	q	[	q	]	s	_	s	b	s	d	t	h	t	j	u	n	u	q	i	v	e	 P	
  g  nameg  !general-journal-options-generator C[R\.,      h      ]45 6        g  
report-obj
		  g  filenamef  general-journal.scm
	~
	 		 	 		  g  nameg  general-journal-renderer C]R^i_`*iabcdi e[if]i6%      g  m
	
	$  g  filenamef  general-journal.scm		
	%	
 	
 	
 	 
 	"
 	"	 	"
 	$	 	$
 	%	 	%
	&		&
	*
	0
		~
	 	 	 	 		 	 		 	 	 
 		
   C6 
